==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntQueenModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntQueenAnimation;
import net.invictusslayer.slayersbeasts.world.entity.AntQueen;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntQueenModel<T extends AntQueen> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_queen_model"), "main");
	private final class_630 root;

	public AntQueenModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_48741(AntQueenAnimation.WALK, limbSwing, limbSwingAmount, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(47, 44).method_32098(-2.0F, -2.5F, -12.0F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-2.5F, -5.0F, -10.0F, 5.0F, 5.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 23).method_32098(-3.5F, -7.5F, -9.0F, 7.0F, 8.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -5.0F, 0.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(32, 33).method_32098(-2.0F, 0.0F, -4.0F, 4.0F, 5.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -11.0F, 3.0F, 0.1745F, 0.0F, 0.0F));

		class_5610 cube_r3 = body.method_32117("cube_r3", class_5606.method_32108().method_32101(33, 0).method_32098(-4.0F, -1.0F, 0.0F, 8.0F, 8.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-5.0F, -2.0F, 1.0F, 10.0F, 10.0F, 13.0F, new class_5605(0.0F))
				.method_32101(32, 23).method_32098(-4.0F, -0.5F, 14.0F, 8.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -11.0F, 3.0F, -0.1745F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(0, 40).method_32098(-3.0F, 0.0F, -2.75F, 6.0F, 3.0F, 3.0F, new class_5605(0.0F))
				.method_32101(33, 44).method_32098(-2.0F, 3.0F, -2.75F, 4.0F, 2.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -8.0F, -10.0F, -0.7418F, 0.0F, 0.0F));

		class_5610 cube_r4 = head.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 10).method_32098(0.0F, 0.0F, -0.25F, 1.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 5.0F, -2.0F, 0.0F, 0.0F, -0.1745F));

		class_5610 cube_r5 = head.method_32117("cube_r5", class_5606.method_32108().method_32101(6, 10).method_32098(-1.0F, 0.0F, -0.25F, 1.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 5.0F, -2.0F, 0.0F, 0.0F, 0.1745F));

		class_5610 cube_r6 = head.method_32117("cube_r6", class_5606.method_32108().method_32101(4, 23).method_32098(-0.5448F, -4.6513F, -1.0582F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -4.0F, -4.0F, 1.7017F, 0.0F, -0.1309F));

		class_5610 cube_r7 = head.method_32117("cube_r7", class_5606.method_32108().method_32101(27, 23).method_32098(0.0F, -5.0F, -0.75F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -1.0F, 0.7854F, -0.4363F, 0.0F));

		class_5610 cube_r8 = head.method_32117("cube_r8", class_5606.method_32108().method_32101(0, 23).method_32098(-0.4552F, -4.6513F, -1.0582F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -4.0F, -4.0F, 1.7017F, 0.0F, 0.1309F));

		class_5610 cube_r9 = head.method_32117("cube_r9", class_5606.method_32108().method_32101(23, 23).method_32098(-1.0F, -5.0F, -0.75F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -1.0F, 0.7854F, 0.4363F, 0.0F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(48, 35).method_32098(-0.5F, 0.0F, -0.5F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(49, 39).method_32098(2.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(44, 33).method_32098(2.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -6.0F, -8.0F, 0.6981F, 0.4363F, 1.0908F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(46, 17).method_32098(-0.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(36, 49).method_32098(3.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(18, 44).method_32098(3.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -5.75F, -5.0F, 0.0F, 0.0F, 0.829F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(14, 46).method_32098(-0.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 48).method_32098(3.25F, -4.0F, 0.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 11).method_32098(3.25F, -5.0F, 0.0F, 10.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -5.75F, -2.0F, -0.48F, -0.6109F, 1.0036F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(0, 6).method_32098(-3.5F, 0.0F, -0.5F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(32, 49).method_32098(-3.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(32, 42).method_32098(-10.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -6.0F, -8.0F, 0.6981F, -0.4363F, -1.0908F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(46, 13).method_32098(-4.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(32, 33).method_32098(-4.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(15, 41).method_32098(-11.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.75F, -5.0F, 0.0F, 0.0F, -0.829F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(0, 46).method_32098(-4.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(28, 46).method_32098(-4.25F, -4.0F, 0.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 9).method_32098(-13.25F, -5.0F, 0.0F, 10.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.75F, -2.0F, -0.48F, 0.6109F, -1.0036F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntQueenModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntQueenAnimation;
import net.invictusslayer.slayersbeasts.client.state.AntQueenRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntQueenModel extends class_583<AntQueenRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_queen_model"), "main");

	public AntQueenModel(class_630 root) {
		super(root);
	}

	public void setupAnim(AntQueenRenderState state) {
		super.method_2819(state);
		method_62102(AntQueenAnimation.WALK, state.field_53450, state.field_53451, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108(), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(47, 44).method_32098(-2.0F, -2.5F, -12.0F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-2.5F, -5.0F, -10.0F, 5.0F, 5.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 23).method_32098(-3.5F, -7.5F, -9.0F, 7.0F, 8.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -5.0F, 0.0F, -0.0873F, 0.0F, 0.0F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(32, 33).method_32098(-2.0F, 0.0F, -4.0F, 4.0F, 5.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -11.0F, 3.0F, 0.1745F, 0.0F, 0.0F));

		class_5610 cube_r3 = body.method_32117("cube_r3", class_5606.method_32108().method_32101(33, 0).method_32098(-4.0F, -1.0F, 0.0F, 8.0F, 8.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-5.0F, -2.0F, 1.0F, 10.0F, 10.0F, 13.0F, new class_5605(0.0F))
				.method_32101(32, 23).method_32098(-4.0F, -0.5F, 14.0F, 8.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -11.0F, 3.0F, -0.1745F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(0, 40).method_32098(-3.0F, 0.0F, -2.75F, 6.0F, 3.0F, 3.0F, new class_5605(0.0F))
				.method_32101(33, 44).method_32098(-2.0F, 3.0F, -2.75F, 4.0F, 2.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -8.0F, -10.0F, -0.7418F, 0.0F, 0.0F));

		class_5610 cube_r4 = head.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 10).method_32098(0.0F, 0.0F, -0.25F, 1.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, 5.0F, -2.0F, 0.0F, 0.0F, -0.1745F));

		class_5610 cube_r5 = head.method_32117("cube_r5", class_5606.method_32108().method_32101(6, 10).method_32098(-1.0F, 0.0F, -0.25F, 1.0F, 1.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, 5.0F, -2.0F, 0.0F, 0.0F, 0.1745F));

		class_5610 cube_r6 = head.method_32117("cube_r6", class_5606.method_32108().method_32101(4, 23).method_32098(-0.5448F, -4.6513F, -1.0582F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -4.0F, -4.0F, 1.7017F, 0.0F, -0.1309F));

		class_5610 cube_r7 = head.method_32117("cube_r7", class_5606.method_32108().method_32101(27, 23).method_32098(0.0F, -5.0F, -0.75F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -1.0F, 0.7854F, -0.4363F, 0.0F));

		class_5610 cube_r8 = head.method_32117("cube_r8", class_5606.method_32108().method_32101(0, 23).method_32098(-0.4552F, -4.6513F, -1.0582F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -4.0F, -4.0F, 1.7017F, 0.0F, 0.1309F));

		class_5610 cube_r9 = head.method_32117("cube_r9", class_5606.method_32108().method_32101(23, 23).method_32098(-1.0F, -5.0F, -0.75F, 1.0F, 5.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, -1.0F, 0.7854F, 0.4363F, 0.0F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(48, 35).method_32098(-0.5F, 0.0F, -0.5F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(49, 39).method_32098(2.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(44, 33).method_32098(2.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -6.0F, -8.0F, 0.6981F, 0.4363F, 1.0908F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(46, 17).method_32098(-0.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(36, 49).method_32098(3.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(18, 44).method_32098(3.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -5.75F, -5.0F, 0.0F, 0.0F, 0.829F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(14, 46).method_32098(-0.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(46, 48).method_32098(3.25F, -4.0F, 0.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 11).method_32098(3.25F, -5.0F, 0.0F, 10.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -5.75F, -2.0F, -0.48F, -0.6109F, 1.0036F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(0, 6).method_32098(-3.5F, 0.0F, -0.5F, 4.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(32, 49).method_32098(-3.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(32, 42).method_32098(-10.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -6.0F, -8.0F, 0.6981F, -0.4363F, -1.0908F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(46, 13).method_32098(-4.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(32, 33).method_32098(-4.25F, -3.0F, 0.0F, 1.0F, 3.0F, 1.0F, new class_5605(0.0F))
				.method_32101(15, 41).method_32098(-11.25F, -4.0F, 0.0F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.75F, -5.0F, 0.0F, 0.0F, -0.829F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(0, 46).method_32098(-4.5F, 0.0F, -0.5F, 5.0F, 2.0F, 2.0F, new class_5605(0.0F))
				.method_32101(28, 46).method_32098(-4.25F, -4.0F, 0.0F, 1.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 9).method_32098(-13.25F, -5.0F, 0.0F, 10.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -5.75F, -2.0F, -0.48F, 0.6109F, -1.0036F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}
